/*
 * Copyright (c) 2014 Cloudera, Inc. All rights reserved.
 */

package com.cloudera.keytrustee;

import com.cloudera.keytrustee.crypto.Fingerprint;
import org.apache.commons.pool2.ObjectPool;
import org.json.JSONArray;

import java.util.Collection;
import java.util.concurrent.TimeoutException;

/**
 * Pool of ClientConnection objects. Implemented using org.apache.commons.pool2.ObjectPool.
 */
class TrusteeClientConnectionPool {

  private final ObjectPool<ClientConnection> connectionPool;

  public TrusteeClientConnectionPool(ObjectPool<ClientConnection> pool) {
    this.connectionPool = pool;
  }

  public ClientConnection getConnection() {
    ClientConnection keyTrusteeConnection = null;
    try {
      keyTrusteeConnection = this.connectionPool.borrowObject();
    } catch (Exception e){
      throw new RuntimeException("Unable to borrow keyTrusteeConnection from pool" + e.toString());
    }
    return keyTrusteeConnection;
  }

  public boolean releaseConnection(ClientConnection keyTrusteeConnection) {
    boolean success = true;
    try {
      this.connectionPool.returnObject(keyTrusteeConnection);
    } catch (Exception e) {
      //ignored
      success = false;
    }
    return success;
  }

  public int getNumActiveConnections() {
    return this.connectionPool.getNumActive();
  }

  public int getNumIdleConnections() {
    return this.connectionPool.getNumIdle();
  }
}
